Crate codex_shell_escalation

Crate codex_shell_escalation 

Structs

EscalateServer
EscalationSession
ExecParams
ExecResult
PreparedExec
ResolvedPermissionProfile
Fully resolved permissions for rerunning an intercepted child process.
Stopwatch

Enums

EscalateAction
EscalationDecision
EscalationExecution
EscalationPermissions

Constants

ESCALATE_SOCKET_ENV_VAR
Exec wrappers read this to find the inherited FD for the escalation socket.

Traits

EscalationPolicy
Decides what action to take in response to an execve request from a client.
ShellCommandExecutor
Adapter for running the shell command after the escalation server has been set up.

Functions

main_execve_wrapper
run_shell_escalation_execve_wrapper

Type Aliases

EscalationPolicyFuture
ShellCommandExecutorFuture