pub enum EscalateAction {
Run,
Escalate,
Deny {
reason: Option<String>,
},
}Variants
Run
The command should be run directly by the client.
Escalate
The command should be escalated to the server for execution.
Deny
The command should not be executed.