pub struct EscalateServer { /* private fields */ }Implementations
Sourceimpl EscalateServer
impl EscalateServer
pub fn new<Policy>( shell_path: PathBuf, execve_wrapper: PathBuf, policy: Policy, ) -> Self
pub async fn exec( &self, params: ExecParams, cancel_rx: CancellationToken, command_executor: Arc<dyn ShellCommandExecutor>, ) -> Result<ExecResult>
Sourcepub fn start_session(
&self,
parent_cancellation_token: CancellationToken,
command_executor: Arc<dyn ShellCommandExecutor>,
) -> Result<EscalationSession>
pub fn start_session( &self, parent_cancellation_token: CancellationToken, command_executor: Arc<dyn ShellCommandExecutor>, ) -> Result<EscalationSession>
Starts an escalation session and returns the environment overlay a shell needs in order to route intercepted execs through this server.
This does not spawn the shell itself. Callers own process creation and only use the returned environment plus the session lifetime handle.